@@ -3,6 +3,7 @@
 
 # imports.
 from syst3m.v1.classes.config import *
+from syst3m.v1.classes import utils
 import platform 
 
 # defaults object class.
@@ -38,14 +39,14 @@ class Defaults(object):
 	):
 		if sudo or cl1.argument_present("--sudo"): sudo = "sudo "
 		else: sudo = ""
-		l_alias = cl1.get_argument("--create-alias")
+		l_alias = cl1.get_argument("--create-alias", required=False)
 		present = "--create-alias" in sys.argv and l_alias == alias
 		base = f"/usr/local/bin"
 		if not os.path.exists(base):
 			base = f"/usr/bin/"
 		path = f"{base}/{alias}"
 		if cl1.argument_present("--force") or cl1.argument_present("--forced") or overwrite or present or not os.path.exists(path):
-			alias = l_alias
+			if l_alias != None: alias = l_alias
 			#file = f"""package={executable}/\nargs=""\nfor var in "$@" ; do\n   	if [ "$args" == "" ] ; then\n   		args=$var\n   	else\n   		args=$args" "$var\n   	fi\ndone\npython3 $package $args\n"""
 			file = f"""#!/usr/bin/env python3\nimport os, sys\npackage="{executable}"\nsys.argv.pop(0)\narguments = sys.argv\ns = ""\nfor i in arguments:\n	if s == "": \n		if " " in i: s = "'"+i+"'"\n		else: s = i\n	else: \n		if " " in i: s += " '"+i+"'"\n		else: s += " "+i\nos.system("python3 "+package+" "+s)"""
 			os.system(f"{sudo}touch {path}")
@@ -66,6 +67,13 @@ class Defaults(object):
 		return Formats.FilePath(path).base(back=back)
 	def get_log_level(self):
 		return cl1.get_argument("--log-level", required=False, empty=0)
-
+	def pwd(self):
+		pwd = utils.__execute_script__("pwd").replace("\n","")
+		while True:
+			if len(pwd) > 0 and pwd[0] == "/": pwd = pwd[1:]
+			elif len(pwd) > 0 and pwd[len(pwd)-1] == "/": pwd = pwd[:-1]
+			elif " " in pwd: pwd = pwd.replace(" ","")
+			else: break
+		return f"/{pwd}/"
 # initialized classes.
 defaults = Defaults()
\ No newline at end of file
